#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
wagtailaltgenerator
----------
Insert image description and tags with the help of computer vision
"""

__title__ = "wagtailaltgenerator"
__version__ = "4.1.2"
__build__ = 412
__author__ = "Martin Sandström"
__license__ = "MIT"
__copyright__ = "Copyright 2016-2020 Martin Sandström"

default_app_config = "wagtailaltgenerator.apps.AltGeneratorAppConfig"
